==> haskell-tasty-discover-5.0.1-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-discover.sh <==
#!/bin/sh
export PATH='/build/haskell-tasty-discover/src/tasty-discover-5.0.1/dist/build/tasty-discover:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-discover
version:              5.0.1
visibility:           public
id:                   tasty-discover-5.0.1-DAJ6nsoL1VZGPbosnruWyY
key:                  tasty-discover-5.0.1-DAJ6nsoL1VZGPbosnruWyY
license:              MIT
copyright:
    2016 Luke Murphy
    2020-2022 John Ky

maintainer:           John Ky <newhoggy@gmail.com>
author:               Luke Murphy
stability:            Experimental
homepage:             https://github.com/haskell-works/tasty-discover
synopsis:             Test discovery for the tasty framework.
description:
    Automatic test discovery and runner for the tasty framework.
    Prefix your test case names and tasty-discover will discover, collect and run them.
    All popular test libraries are covered. Configure once and then just write your tests.
    Avoid forgetting to add test modules to your Cabal/Hpack files.
    Tasty ingredients are included along with various configuration options for different
    use cases.
    Please see the `README.md` below for how to get started.

category:             Testing
abi:                  0d1ed62ee234ff48fb3c749bca2fe4cc
exposed:              True
exposed-modules:
    Test.Tasty.Discover Test.Tasty.Discover.Internal.Config
    Test.Tasty.Discover.Internal.Driver
    Test.Tasty.Discover.Internal.Generator
    Test.Tasty.Discover.TastyInfo Test.Tasty.Discover.Version

hidden-modules:       Paths_tasty_discover
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-discover-5.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-discover-5.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-discover-5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-discover
hs-libraries:         HStasty-discover-5.0.1-DAJ6nsoL1VZGPbosnruWyY
depends:
    Glob-0.10.2-JfA0ye8zAkc8ATfWN2Qrof base-4.17.2.1 containers-0.6.7
    filepath-1.4.2.2 tasty-1.4.3-47zEnB2ZNk4EGBe54KqkRX

haddock-interfaces:
    /usr/share/doc/haskell-tasty-discover/html/tasty-discover.haddock

haddock-html:         /usr/share/doc/haskell-tasty-discover/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-discover-5.0.1-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-discover.sh <==
#!/bin/sh
export PATH='/build/haskell-tasty-discover/src/tasty-discover-5.0.1/dist/build/tasty-discover:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-discover
version:              5.0.1
visibility:           public
id:                   tasty-discover-5.0.1-199JxlQuE6d13tK0TS9xHu
key:                  tasty-discover-5.0.1-199JxlQuE6d13tK0TS9xHu
license:              MIT
copyright:
    2016 Luke Murphy
    2020-2022 John Ky

maintainer:           John Ky <newhoggy@gmail.com>
author:               Luke Murphy
stability:            Experimental
homepage:             https://github.com/haskell-works/tasty-discover
synopsis:             Test discovery for the tasty framework.
description:
    Automatic test discovery and runner for the tasty framework.
    Prefix your test case names and tasty-discover will discover, collect and run them.
    All popular test libraries are covered. Configure once and then just write your tests.
    Avoid forgetting to add test modules to your Cabal/Hpack files.
    Tasty ingredients are included along with various configuration options for different
    use cases.
    Please see the `README.md` below for how to get started.

category:             Testing
abi:                  947e7980e254d4653cbaba2a96b3630a
exposed:              True
exposed-modules:
    Test.Tasty.Discover Test.Tasty.Discover.Internal.Config
    Test.Tasty.Discover.Internal.Driver
    Test.Tasty.Discover.Internal.Generator
    Test.Tasty.Discover.TastyInfo Test.Tasty.Discover.Version

hidden-modules:       Paths_tasty_discover
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-discover-5.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-discover-5.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-discover-5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-discover
hs-libraries:         HStasty-discover-5.0.1-199JxlQuE6d13tK0TS9xHu
depends:
    Glob-0.10.2-5xclHbvDGhqEu2LdSOR2mc base-4.17.2.1 containers-0.6.7
    filepath-1.4.2.2 tasty-1.4.3-EjyvceRmrrr5McFRQ3mzqf

haddock-interfaces:
    /usr/share/doc/haskell-tasty-discover/html/tasty-discover.haddock

haddock-html:         /usr/share/doc/haskell-tasty-discover/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
